NoStatic

Struct NoStatic 

pub struct NoStatic;
For devices that don’t need any associated static data, This NoStatic type will take no space and generate no code, and has the const constructor needed for the type.